// subPackageMarketing/page/pages/activityOrder/activityOrder.js
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util')
import { Integer } from '../../../../utils/integerDigitalConvertion'
let app = getApp();

wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    id : '',
    activityInfo : {},
    orderBtnText : '立即预约',
    userOrderStatus : false,
    showInvite : false,
    shareObj : {
      title: '',
      path: '',
      imageUrl: ''
    }
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    if(options.id){
      wx.showLoading({
        title: '加载中..',
      });
      this.data.id = options.id;
      wx.showLoading({
        title: '数据加载中..',
      });
      this.getActivityInfo();
    }
  },

  //获取活动详情
  getActivityInfo(){
    wxService.post(`/marketing/bookingActivitySet/findById?id=${this.data.id}`).then(res => {
      if(res){
        let obj = res.data.data ? res.data.data : null;
        if(obj){
          this.data.activityInfo = obj;
          this.setData({
            activityInfo : this.data.activityInfo
          });

          this.setUserOrderStatus(this.data.id);
          //生成触点
          this.generatePoint();
        }
      }
    })
  },

  //设置用户预约状态
  setUserOrderStatus(id){
    let baseUserInfo = wx.getStorageSync('_baseUserInfo');
    if(!baseUserInfo){
      this.setData({
        currentHasUserInfo : false,
      });
      return ;
    }

    this.setData({
      currentHasUserInfo : true,
    });

    wxService.post(`/merchant/message/wxSubMsgSubscride/getByParams`,{
      memberId : baseUserInfo.memberId,
      businessId : id
    }).then(res => {
      if(res){
        let data = res.data.data ? res.data.data : [];
        if(data.length == 0){
          this.setData({
            orderBtnText : '立即预约',
            userOrderStatus : false,
          });
        }
        else{
          this.setData({
            orderBtnText : '已预约',
            userOrderStatus : true,
          });
        }
      }
    });
  },

  // let enCodeUrl = encodeURIComponent(url);
  // let sharePath = `/subPackage/page/pages/h5/h5page?url=${enCodeUrl}`

  //立即预约
  onTapOrderNow(){
    wxService.post(`/marketing/bookingActivitySet/checkActivityTakeeffect?id=${this.data.activityInfo.id}`).then(res => {
      if(res){
        if(res.data.data){
          //先判断是否已经预约过
          if(this.data.userOrderStatus){
            wx.showModal({
              title : '预约成功',
              showCancel: false,
              confirmText : '确定',
              content : '您已订阅消息通知~',
              confirmColor : app.globalData.themeColor,
              success(){},
            })
          }
          else{
            if(this.data.activityInfo.templateId){
              this.getOrderActivityInfo(this.data.activityInfo.templateId,this.data.activityInfo);
            }
          }
        }
        else{
          wx.showToast({
            title: '不在活动预约时间范围内',
            icon : 'none'
          });
        }
      }
    });
  },

  //获取预约信息
  getOrderActivityInfo(id,info){
    wxService.get(`/merchant/message/wxTemplateMappingMiniProgram/${id}`).then(res => {
      if(res){
        let templateObj = res.data.data ? res.data.data : null;
        if(templateObj){
          let templateId = templateObj.templateId;
          wx.requestSubscribeMessage({
            tmplIds: [templateId],
            success: (reqRes) => {
              this.orderActivity(info.id,templateId,info);
            },
            complete: (reqComp) => {}
          })
        }
      }
    });
  },

  //预约活动
  orderActivity(activityId,templateId,info){
    let self = this;
    let baseUserInfo = wx.getStorageSync('_baseUserInfo');
    wxService.post(`${'/merchant/message/wxSubMsgSubscride/member/subscribe'}`, {
      businessId: activityId,
      memberId: baseUserInfo.memberId,
      templateId : templateId,
    }).then(resp => {
      wx.showModal({
        title : '预约成功',
        showCancel: false,
        confirmText : '确定',
        content : info.prompt,
        confirmColor : app.globalData.themeColor,
        success(){
          self.award(activityId);
        },
      })
    });
  },
  //发奖接口
  award(activityId){
    let baseUserInfo = wx.getStorageSync('_baseUserInfo');
    wxService.post(`/marketing/bookingActivitySet/award`,{
      activityId : activityId,
      memberId: baseUserInfo.memberId,
      type : 0
    }).then(res => {});
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function (res) {
    this.onTapCloseModal();
    return this.data.shareObj;
  },
  //生成触点
  generatePoint(){
    let content = {
      title: this.data.activityInfo.name,
      id: this.data.activityInfo.id,
      url: this.data.activityInfo.imgUrl
    }
    let tentacleInfo = {
      content: JSON.stringify(content),
      contentId: this.data.activityInfo.id,
      contentType: app.globalData.contants.SHARE_TYPE.PRODUCT_DETAIL, //内容类型 STAFF_RECOMMAND
      title: this.data.activityInfo.name, //标题
      type: 2// 1:门店,2:员工(暂时不做),3:会员,4:第三方外部渠道,5:智能营销
    }

    wxService.getTentacleContent(tentacleInfo).then(res => {
      if (res && res.id) {
        let tentacleId = res.id;
        let inner_id = Integer.digit(this.data.activityInfo.id, 10, 64);
        let inner_tentacleId = Integer.digit(tentacleId, 10, 64);
        var path = 'subPackageMarketing/page/pages/activityOrder/activityOrder' + '?i=' + inner_id + '&t=' + inner_tentacleId;

        this.data.shareObj = {
          title: this.data.activityInfo.name,
          path: path,
          imageUrl: this.data.activityInfo.imgUrl
        }
        this.setData({
          shareObj : this.data.shareObj
        });

        //生成二维码
        this.genteratorQrcode(inner_id,inner_tentacleId);
      }
    });  
  },
  //生成带触点的二维码
  genteratorQrcode(i,t){
    let data = {
      "autoColor": true,
      // "page": 'subPackageMarketing/page/pages/activityOrder/activityOrder',
      "page": 'pages/userCenter/userCenter',
      "scene": `i=${i}&t=${t}`,
      "width": 260
    }
    wxService.post(`/marketing/quickMark/getAppQrCodePicture`, data).then(res => {
      const { result, data } = res.data
      if (result == 0) {
        let url = app.globalData.imageUrl + data;
        this.data.activityInfo.qrcode = url;
      }
    });
  },
  //邀请好友
  onTapInviteFriends(){
    this.setData({
      showInvite : true
    });
  },
  //关闭
  onTapCloseModal(){
    this.setData({
      showInvite : false
    });
  },
  //生成海报
  onTapGeneratePoster(){
    if(!this.data.activityInfo.imgUrl){
      wx.showToast({
        title: '该活动暂未设置分享封面，请商户配置后再生成海报~',
        icon : 'none'
      });

      return ;
    }

    wx.setStorageSync('activityOrderInfo', this.data.activityInfo);
    this.setData({
      showInvite : false
    });
    wx.navigateTo({
      url: '/subPackageMarketing/page/pages/activityPoster/activityPoster',
    });
  },
});