// subPackageMarketing/page/pages/activityPoster/activityPoster.js
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util')
const envInfo = require('../../../../config/index').envInfo
const app = getApp()
const deviceWidth = app.globalData.systemInfo.windowWidth;
const isIPX = app.globalData.systemInfo.model == 'iPhone X';
let deviceHeight = app.globalData.systemInfo.windowHeight;
const ratio = deviceWidth / deviceHeight;
// 单位转换
const rpx2px = rpx => deviceWidth / 750 * rpx

/**
 * 设置文本行数，超出省略
 * @param {object} ctx canvas实例
 * @param {string} text 文本数据
 * @param {number} lineNum 行数
 * @param {number} width 文字宽度最宽默认 620rpx
 * 返回 由每一行组成的数组
 */
const setTextLine = (ctx, text, lineNum = 1, width = 610) => {
  const str_arr = String(text).split('')
  width = rpx2px(width)
  let temp = ''
  // 分行
  let row_arr = str_arr.reduce((arr, word) => {
    const w = ctx.measureText(temp).width
    if (w < width) {
      temp += word;
    } else {
      arr.push(temp)
      temp = word
    }
    return arr
  }, [])
  row_arr.push(temp)
  temp = ''

  // 判断需要的行数
  row_arr = row_arr.slice(0, lineNum)
  if (row_arr.length > 1) {
    // 最后一行超出则省略号
    row_arr[row_arr.length - 1].split().every(v => {
      temp += v
      if (ctx.measureText(temp).width > (width - 20)) {
        temp += '...'
        return false
      }
      return true
    })
    row_arr.splice(row_arr.length - 1, 1, temp)
  }

  return row_arr
}


wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    height : deviceHeight + 'px',
    width : deviceWidth + 'px',
    activityInfo : {},
    posterImgInfo : null,
    qrcodeImgInfo : null,
    saveImgUrl : '',
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu();
    let activityInfo = wx.getStorageSync('activityOrderInfo');
    if(activityInfo){
      wx.showLoading({
        title: '海报制作中..',
      });
      //调用处理信息
      this.data.activityInfo = activityInfo;
      console.log(this.data.activityInfo)
      this.downloadSharePosterImg();
    }
  },

  //下载海报图
  downloadSharePosterImg(){
    var that = this;
    let posterImgUrl = this.data.activityInfo.imgUrl;
    wx.downloadFile({
      url: posterImgUrl,
      success: function (res) {
        if (res.statusCode === 200) {
          var sharePosterUrl = res.tempFilePath;
          that.calculateImg(sharePosterUrl,res => {
            that.data.posterImgInfo = res;
            //下载二维码
            that.downloadQrcode();
          })
        }
      },
      fail: function () {
        wx.hideLoading();
        wx.showToast({
          title: '海报图下载失败！',
          icon: 'none',
          duration: 2000
        });
      },
    })
  },

  //下载二维码
  downloadQrcode(){
    var that = this;
    let imgUrl = this.data.activityInfo.qrcode;
    wx.downloadFile({
      url: imgUrl,
      success: function (res) {
        if (res.statusCode === 200) {
          var sharePosterUrl = res.tempFilePath;
          that.calculateImg(sharePosterUrl,res => {
            that.data.qrcodeImgInfo = res;
            that.drawCanvas();
          })
        }
      },
      fail: function () {
        wx.hideLoading();
        wx.showToast({
          title: '二维码下载失败！',
          icon: 'none',
          duration: 2000
        });
      },
    })
  },

  //获取图片规格
  calculateImg(src, cb){
    var that = this;
    wx.getImageInfo({
      src: src,
      success(res) {
        cb(res);
      }
    })
  },

  //画canvas
  drawCanvas(){
    let self = this;
    console.log(this.data)
    console.log(ratio,deviceWidth,deviceHeight)
    const ctx = wx.createCanvasContext('myCanvas', this)
    const canvasWidth = deviceWidth
    const canvasHeight = deviceHeight
    // 绘制背景，填充满整个canvas画布
    ctx.setFillStyle('#fff')
    ctx.fillRect(0, 0, canvasWidth, canvasHeight)
    //计算海报宽高
    //先把宽度撑满（默认海报的宽度是大于等于6splus宽度）
    let posterShareImgWidth = this.data.posterImgInfo.width, posterShareImgHeight = this.data.posterImgInfo.height;
    let ratioImgHeight = posterShareImgHeight*(deviceWidth/posterShareImgWidth);
    ctx.drawImage(this.data.posterImgInfo.path, 0, 0, deviceWidth, ratioImgHeight);

    //计算剩下的高度
    let leftHeight = deviceHeight - ratioImgHeight;
    console.log('leftHeight---',leftHeight)
    //设置二维码的宽高 
    let qrcodeWidth = parseInt(leftHeight/3)*2 , qrcodeHeight = qrcodeWidth;
    let qrcodeX = deviceWidth - qrcodeWidth - 25 , qrcodeY =  ratioImgHeight + (qrcodeWidth/3);
    console.log(qrcodeX,qrcodeY,qrcodeWidth,qrcodeHeight)
    ctx.drawImage(this.data.qrcodeImgInfo.path, qrcodeX, qrcodeY, qrcodeWidth, qrcodeHeight);
    //画文案
    //第一行文案 邀请您参与 
    let firstLineTextX = 25, firstLineTextY = ratioImgHeight + (qrcodeWidth/3) + qrcodeHeight/4;
    ctx.setFillStyle('#666')
    ctx.setFontSize(14)
    ctx.fillText('邀请您参与', firstLineTextX,firstLineTextY);
    //第二行文案
    let SecondLineTextX = 25, SecondLineTextY = firstLineTextY + 25;
    ctx.setFillStyle('#000')
    ctx.setFontSize(14)
    ctx.fillText(`【${this.data.activityInfo.name}】`, SecondLineTextX,SecondLineTextY);
    // ctx.fillText(`【测试一下最长能多上的测试】`, SecondLineTextX,SecondLineTextY);

    //第三行文案
    let thirdLineTextX = 25, thirdLineTextY = SecondLineTextY + 25;
    ctx.setFillStyle('#666')
    ctx.setFontSize(14)
    ctx.fillText('长按扫码有惊喜', thirdLineTextX,thirdLineTextY);

    // return ;
    ctx.stroke()
    ctx.draw(false , () => {
      wx.canvasToTempFilePath({
        canvasId: 'myCanvas',
        quality: 1,
        success: result => {
          wx.hideLoading();
          this.data.saveImgUrl = result.tempFilePath;
          this.savePosterImg(this.data.saveImgUrl);
        }
      }, self);
    });
  },
  //canvas点击
  onTapSave(){
    if(this.data.saveImgUrl){
      this.savePosterImg(this.data.saveImgUrl);
    }
    else{
      wx.showToast({
        title: '请等待海报生成完成后保存',
        icon : 'none'
      });
    }
  },
  //保存海报
  savePosterImg(tempFilePath){
    wx.showModal({
      title : '保存海报',
      confirmText : '确定',
      content : '海报已生成，是否保存海报到相册？',
      confirmColor : app.globalData.themeColor,
      success(res){
        if(res.confirm){
          wx.saveImageToPhotosAlbum({
            filePath: tempFilePath,
            success(){
              wx.showToast({
                title: '保存成功,快去相册看看吧~',
                icon : 'none'
              });
            }
          });
        }
      },
    })
  }
 
})